@@ -12,10 +12,10 @@ class ZiggeoAuth:
         pad = lambda s: s + (BS - len(s) % BS) * chr(BS - len(s) % BS)
 
         try:
-            hashed_key = hashlib.md5(self.__application.encryption_key).hexdigest()
+            hashed_key = hashlib.md5(self.__application.encryption_key.encode('utf-8')).hexdigest()
             iv = binascii.b2a_hex(os.urandom(8))
-            encrypted = binascii.hexlify(AES.new(hashed_key, AES.MODE_CBC, iv).encrypt(pad(plaintext)))
-            return iv + encrypted
+            encrypted = binascii.hexlify(AES.new(hashed_key.encode('utf-8'), AES.MODE_CBC, iv).encrypt(pad(plaintext).encode('utf-8')))
+            return str(iv + encrypted, 'utf-8')
         except TypeError:
             md=hashlib.md5()
             md.update(self.__application.encryption_key.encode('utf-8'))
